Keen | Colors
Description: Keen custom colors

# Customer Relationship Management

New Order

### Colors

Reports

### State

You can apply Bootstrap and Keen state color helper classes to the most of the Keen's components:

State | Preview | Class postfix | Usage example
--- | --- | --- | ---
Bootstrap States
Success |  | `*-success` | `btn-success` `k-font-success`
Warning |  | `*-warning` | `btn-warning` `k-font-warning`
Danger |  | `*-danger` | `btn-danger` `k-font-danger`
Info |  | `*-info` | `btn-info` `k-font-info`
Primary |  | `*-primary` | `btn-primary` `k-font-primary`
Secondary |  | `*-secondary` | `btn-secondary` `k-font-secondary`
Dark |  | `*-dark` | `btn-dark` `k-font-dark`
Keen Custom States
Brand |  | `*-brand` | `btn-success` `k-font-brand`
Accent |  | `*-accent` | `btn-accent` `k-font-accent`
Focus |  | `*-focus` | `btn-focus` `k-font-focus`
Metal |  | `*-metal` | `btn-metal` `k-font-metal`
Light |  | `*-light` | `btn-light` `k-font-light`

### Base Colors

You can apply Keen's base color helper classes to the most of the Keen's components:

Level | Preview | Class example
--- | --- | ---
Label Classes
Level 1 | Font Color BG Color | `kt-label-font-color-1` `kt-label-bg-color-1`
Level 2 | Font Color BG Color | `kt-label-font-color-2` `kt-label-bg-color-2`
Level 3 | Font Color BG Color | `kt-label-font-color-3` `kt-label-bg-color-3`
Level 4 | Font Color BG Color | `kt-label-font-color-4` `kt-label-bg-color-4`
Shape Classes
Level 1 | Font Color BG Color | `kt-shape-font-color-1` `kt-shape-bg-color-1`
Level 2 | Font Color BG Color | `kt-shape-font-color-2` `kt-shape-bg-color-2`
Level 3 | Font Color BG Color | `kt-shape-font-color-3` `kt-shape-bg-color-3`
Level 4 | Font Color BG Color | `kt-shape-font-color-4` `kt-shape-bg-color-4`

### Examples

Apply state color classes to any typography element:
Success state text Warning state text Info state text
Danger state text Primary state text Focus state text
Apply base color classes to any typography element:
Label color level 4 Label color level 3 Label color level 2 Label color level 1
Apply color classes to any component:
Primary Success Warning Danger Metal Brand Focus
Success Warning Danger Dark Brand Focus
new pending 203 hot fixed in process completed focus accent
Well done! You successfully read this important alert message.
Well done! You successfully read this important alert message.
Well done! You successfully read this important alert message.
Well done! You successfully read this important alert message.
25%

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!